@@ -30,7 +30,6 @@ import java.util.regex.Pattern;
 import javax.xml.namespace.QName;
 import javax.xml.stream.XMLStreamConstants;
 import javax.xml.stream.XMLStreamReader;
-import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.databinding.DataReader;
 import org.apache.cxf.endpoint.Endpoint;
 import org.apache.cxf.interceptor.AbstractInDatabindingInterceptor;
@@ -50,6 +49,8 @@ import org.apache.cxf.service.model.ServiceModelUtil;
 import org.apache.cxf.staxutils.DepthXMLStreamReader;
 import org.apache.cxf.staxutils.StaxUtils;
 import org.apache.ws.commons.schema.XmlSchemaElement;
+import com.openexchange.java.StringAllocator;
+import com.openexchange.log.CommonsLoggingLogger;
 
 /**
  * {@link DocLiteralInInterceptor} - A rewrite of {@code org.apache.cxf.interceptor.DocLiteralInInterceptor} class for less strict parsing
@@ -61,7 +62,7 @@ public class DocLiteralInInterceptor extends AbstractInDatabindingInterceptor {
     public static final String KEEP_PARAMETERS_WRAPPER = DocLiteralInInterceptor.class.getName()
         + ".DocLiteralInInterceptor.keep-parameters-wrapper";
 
-    private static final Logger LOG = LogUtils.getL7dLogger(DocLiteralInInterceptor.class);
+    private static final Logger LOG = new CommonsLoggingLogger(DocLiteralInInterceptor.class);
 
     public DocLiteralInInterceptor() {
         super(Phase.UNMARSHAL);
@@ -131,6 +132,12 @@ public class DocLiteralInInterceptor extends AbstractInDatabindingInterceptor {
                             if (fault.getCause() instanceof javax.xml.bind.UnmarshalException) {
                                 final Throwable linkedException = ((javax.xml.bind.UnmarshalException) fault.getCause()).getLinkedException();
                                 if (linkedException != null && linkedException.getClass().getName().indexOf("SAXParseException") >= 0) {
+                                    {
+                                        final StringAllocator sb = new StringAllocator(fault.getMessage());
+                                        sb.append('\n');
+                                        appendStackTrace(fault.getStackTrace(), sb);
+                                        LOG.severe(sb.toString());
+                                    }
                                     final String[] info = extractUnexpectedElement(linkedException.getMessage());
                                     if (null != info) {
                                         final String m ;
@@ -365,4 +372,34 @@ public class DocLiteralInInterceptor extends AbstractInDatabindingInterceptor {
             return Boolean.parseBoolean(keepParametersWrapperFlag.toString());
         }
     }
+
+    private static void appendStackTrace(final StackTraceElement[] trace, final com.openexchange.java.StringAllocator sb) {
+        if (null == trace) {
+            return;
+        }
+        final String lineSeparator = System.getProperty("line.separator");
+        for (final StackTraceElement ste : trace) {
+            final String className = ste.getClassName();
+            if (null != className) {
+                sb.append("    at ").append(className).append('.').append(ste.getMethodName());
+                if (ste.isNativeMethod()) {
+                    sb.append("(Native Method)");
+                } else {
+                    final String fileName = ste.getFileName();
+                    if (null == fileName) {
+                        sb.append("(Unknown Source)");
+                    } else {
+                        final int lineNumber = ste.getLineNumber();
+                        sb.append('(').append(fileName);
+                        if (lineNumber >= 0) {
+                            sb.append(':').append(lineNumber);
+                        }
+                        sb.append(')');
+                    }
+                }
+                sb.append(lineSeparator);
+            }
+        }
+    }
+
 }
